@@ -4,6 +4,8 @@ Implementation of the
 to the tus protocol.
 """
 
+from __future__ import annotations
+
 import asyncio
 import base64
 import io
@@ -38,7 +40,7 @@ async def create(
     url: yarl.URL,
     file: Optional[BinaryIO],
     metadata: common.Metadata,
-    ssl: common.SSLArgument = None,
+    ssl: Optional[common.SSLArgument] = None,
     headers: Optional[Mapping[str, str]] = None,
 ) -> yarl.URL:
     """Create an upload.
